'**********************************************************************
' Application Note: Using the MAX1668
'-----------------------------------------------------
'
' Program-ID.: MAX1668.bas.
' Date...... : 22 / 05 / 2005
' Description: Example program for MAX1668 Multichannel Remote/Local
' Temperature Sensors
' write and read routines.
'
' Author : Roland van leusden (sayang@zonnet.nl).
'
' Setup for the AT90S2313 using portd.6 for SDA and Portd.5 for SCL.
' (Futurlec ET-JRAVR board)
' See page 1 from MAX1668 datasheet for shematic. (www.maxim-ic.com)
'
' This program provides an example for writing to and reading from
' a MAX1668 device wired with AO,A1 open.
'
'
'**********************************************************************
$regfile = "2313def.dat" ' Change for your AVR.
$crystal = 4000000 ' 4 MHz Crystal.
$baud = 19200  ' Output at 19200 baud.

'**********************************************************************
'** Set up Data Direction Registers and ports - Do this before defining I2C pins!
'**********************************************************************
' Port B
Portb = &B0000_0000 ' Set All Port Pins Low
Ddrb = &B1111_1111 ' Set Unused Pins As Outputs.
' Port D
Portd = &B0000_0000 ' All low - with push-pull output
Ddrd = &B1111_1111 ' with internal pullups.

'**********************************************************************
'** Define and initialize I2C pins **
'**********************************************************************
Config Sda = Portd.6 ' I2C Data.
Config Scl = Portd.5  ' I2C Clock.

'**********************************************************************

'**********************************************************************
'
'** Declare subroutines **
'**********************************************************************
'
' This subroutine writes data to the I2C MAX1668.
'
Declare Sub I2c_max1668_write(byval Cmd As Byte , Byval Msb As Byte)
'
' This subroutine reads data from the I2C MAX1668.
'
Declare Sub I2c_max1668_read(byval Cmd As Byte , Msb As Byte)
'**********************************************************************
'** Define working variables and constants **
'**********************************************************************

Dim Max1668_adress_w As Byte
Max1668_adress_w = &H54 'A1 & A0 open, see datasheet

Dim Max1668_adress_r As Byte
Max1668_adress_r = &H55 'A1 & A0 open, see datasheet

Dim Counter_1 As Byte
Dim Cmd As Byte
Dim Msb As Byte



'**********************************************************************
'** Actual work starts here. **
'**********************************************************************


Main:

Msb = &H00
Call I2c_max1668_read(&Hfe , Msb) ' Read MSB
Print "Manufacture ID : " ; Hex(msb) ' MSB to serial port

Msb = &H00
Call I2c_max1668_read(&Hff , Msb)  ' Read MSB
Print "Device ID : " ; Hex(msb) ' MSB to serial port

Msb = &H00
Call I2c_max1668_read(&H05 , Msb) ' Read MSB
Print "Status byte 1 : " ; Bin(msb) ' MSB to serial port

Msb = &H00
Call I2c_max1668_read(&H06 , Msb) ' Read MSB
Print "Status byte 2 : " ; Bin(msb) ' MSB to serial port

Msb = &H00
Call I2c_max1668_read(&H00 , Msb) ' Read MSB
Print "MAX1668 Local Temperature: " ; Msb ' MSB to serial port

Msb = &H09
Call I2c_max1668_write(&H15 , Msb) ' Write remote DX1 THIGH limit

Msb = &H00
Call I2c_max1668_write(&H16 , Msb) ' Write remote DX1 Tlow limit

Msb = &H00
Call I2c_max1668_read(&H0a , Msb) ' Read MSB
Print "Remote DX1 Thigh limit: " ; Msb ' MSB to serial port

Msb = &H00
Call I2c_max1668_read(&H0b , Msb) ' Read MSB
Print "Remote DX1 Tlow limit: " ; Msb ' MSB to serial port

Counter_1 = 0

Do

Msb = &H00
Call I2c_max1668_read(&H01 , Msb) ' Read MSB
Print "Remote DX1 temperature: " ; Msb ' MSB to serial port
Wait 1
Counter_1 = Counter_1 + 1

Loop Until Counter_1 = 10

End 'end program




'**********************************************************************
'** Define Subroutines **
'**********************************************************************
Sub I2c_max1668_write(byval Cmd As Byte , Msb As Byte)
' Writes data to the I2C MAX1668.

 I2cstart 'Generate A Start Condition
 I2cwbyte Max1668_adress_w 'Transmit The "ADDRESS and WRITE" Byte
 I2cwbyte Cmd  'Transmit The Command Byte
 I2cwbyte Msb 'Transmit Data Byte
 I2cstop 'Generate a STOP condition
 'Waitus 50  'Some delay may be necessary for back to back transmitions

End Sub

Sub I2c_max1668_read(byval Cmd As Byte , Msb As Byte)
' Read data from the I2C MAX1668

 I2cstart 'Generate START condition
 I2cwbyte Max1668_adress_w 'Transmit The "ADDRESS and WRITE" Byte
 I2cwbyte Cmd 'Transmit The Command Byte
 I2cstart  'Generate a REPEATED-START condition
 I2cwbyte Max1668_adress_r 'Transmit ADDRESS with READ command
 I2crbyte Msb , Nack 'Receive DATA byte (MSB) and don't acknowledge
 I2cstop 'Generate a STOP condition

End Sub

